==> jersey-server-1.1.5-sources.jar: com/sun/jersey/server/impl/application/DeferredResourceConfig.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://jersey.dev.java.net/CDDL+GPL.html
 * or jersey/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at jersey/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.sun.jersey.server.impl.application;

import com.sun.jersey.api.container.ContainerException;
import com.sun.jersey.api.core.DefaultResourceConfig;
import com.sun.jersey.core.spi.component.ComponentProvider;
import com.sun.jersey.core.spi.component.ProviderFactory;
import java.util.Collections;
import java.util.Set;
import java.util.logging.Logger;
import javax.ws.rs.core.Application;

/**
 *
 * @author Paul.Sandoz@Sun.Com
 */
public class DeferredResourceConfig extends DefaultResourceConfig {

    private static final Logger LOGGER =
            Logger.getLogger(DeferredResourceConfig.class.getName());

    private final Class<? extends Application> appClass;

    private final Set<Class<?>> defaultClasses;
    
    public DeferredResourceConfig(Class<? extends Application> appClass) {
        this(appClass, Collections.<Class<?>>emptySet());
    }

    public DeferredResourceConfig(Class<? extends Application> appClass, 
            Set<Class<?>> defaultClasses) {
        this.appClass = appClass;
        this.defaultClasses = defaultClasses;
    }

    public Application getApplication(ProviderFactory pf) {
        ComponentProvider cp = pf.getComponentProvider(appClass);
        if (cp == null) {
            throw new ContainerException("");
        }
        Application app = (Application)cp.getInstance();
        
        if (app.getClasses().isEmpty() && app.getSingletons().isEmpty()) {
            LOGGER.info("Instantiating the Application class, named " +
                    appClass.getName() +
                    ". The following root resource and provider classes are registered: " + defaultClasses);
            DefaultResourceConfig drc = new DefaultResourceConfig(defaultClasses);
            drc.add(app);
            return drc;
        } else {
            LOGGER.info("Instantiating the Application class, named " +
                    appClass.getName());
            return app;
        }
    }
}

==> jersey-server-1.2-sources.jar: com/sun/jersey/server/impl/application/DeferredResourceConfig.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://jersey.dev.java.net/CDDL+GPL.html
 * or jersey/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at jersey/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.sun.jersey.server.impl.application;

import com.sun.jersey.api.container.ContainerException;
import com.sun.jersey.api.core.DefaultResourceConfig;
import com.sun.jersey.core.spi.component.ComponentProvider;
import com.sun.jersey.core.spi.component.ProviderFactory;
import java.util.Collections;
import java.util.Set;
import java.util.logging.Logger;
import javax.ws.rs.core.Application;

/**
 *
 * @author Paul.Sandoz@Sun.Com
 */
public class DeferredResourceConfig extends DefaultResourceConfig {

    private static final Logger LOGGER =
            Logger.getLogger(DeferredResourceConfig.class.getName());

    private final Class<? extends Application> appClass;

    private final Set<Class<?>> defaultClasses;
    
    public DeferredResourceConfig(Class<? extends Application> appClass) {
        this(appClass, Collections.<Class<?>>emptySet());
    }

    public DeferredResourceConfig(Class<? extends Application> appClass, 
            Set<Class<?>> defaultClasses) {
        this.appClass = appClass;
        this.defaultClasses = defaultClasses;
    }

    public Application getApplication(ProviderFactory pf) {
        ComponentProvider cp = pf.getComponentProvider(appClass);
        if (cp == null) {
            throw new ContainerException("");
        }
        Application app = (Application)cp.getInstance();
        
        if ((app.getClasses() == null || app.getClasses().isEmpty()) &&
                (app.getSingletons() == null || app.getSingletons().isEmpty())) {
            LOGGER.info("Instantiating the Application class, named " +
                    appClass.getName() +
                    ". The following root resource and provider classes are registered: " + defaultClasses);
            DefaultResourceConfig drc = new DefaultResourceConfig(defaultClasses);
            drc.add(app);
            return drc;
        } else {
            LOGGER.info("Instantiating the Application class, named " +
                    appClass.getName());
            return app;
        }
    }
}
